/*
    ! tailwindcss v3.4.1 | MIT License | https://tailwindcss.com
    */

  /*
    1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)
    2. Allow adding a border to an element by just adding a border-width. (https://github.com/tailwindcss/tailwindcss/pull/116)
    */

    *,
    ::before,
    ::after {
      box-sizing: border-box;
      /* 1 */
      border-width: 0;
      /* 2 */
      border-style: solid;
      /* 2 */
      border-color: #e5e7eb;
      /* 2 */
    }
  
    ::before,
    ::after {
      --tw-content: "";
    }
  
    /*
      1. Use a consistent sensible line-height in all browsers.
      2. Prevent adjustments of font size after orientation changes in iOS.
      3. Use a more readable tab size.
      4. Use the user's configured `sans` font-family by default.
      5. Use the user's configured `sans` font-feature-settings by default.
      6. Use the user's configured `sans` font-variation-settings by default.
      7. Disable tap highlights on iOS
      */
  
    html,
    :host {
      line-height: 1.5;
      /* 1 */
      -webkit-text-size-adjust: 100%;
      /* 2 */
      -moz-tab-size: 4;
      /* 3 */
      tab-size: 4;
      /* 3 */
      font-family: ui-sans-serif, system-ui, sans-serif, "Apple Color Emoji",
        "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
      /* 4 */
      font-feature-settings: normal;
      /* 5 */
      font-variation-settings: normal;
      /* 6 */
      -webkit-tap-highlight-color: transparent;
      /* 7 */
    }
  
    /*
      1. Remove the margin in all browsers.
      2. Inherit line-height from `html` so users can set them as a class directly on the `html` element.
      */
  
    body {
      margin: 0;
      /* 1 */
      line-height: inherit;
      /* 2 */
    }
  
    /*
      1. Add the correct height in Firefox.
      2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
      3. Ensure horizontal rules are visible by default.
      */
  
    hr {
      height: 0;
      /* 1 */
      color: inherit;
      /* 2 */
      border-top-width: 1px;
      /* 3 */
    }
  
    /*
      Add the correct text decoration in Chrome, Edge, and Safari.
      */
  
    abbr:where([title]) {
      text-decoration: underline dotted;
    }
  
    /*
      Remove the default font size and weight for headings.
      */
  
    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
      font-size: inherit;
      font-weight: inherit;
    }
  
    /*
      Reset links to optimize for opt-in styling instead of opt-out.
      */
  
    a {
      color: inherit;
      text-decoration: inherit;
    }
  
    /*
      Add the correct font weight in Edge and Safari.
      */
  
    b,
    strong {
      font-weight: bolder;
    }
  
    /*
      1. Use the user's configured `mono` font-family by default.
      2. Use the user's configured `mono` font-feature-settings by default.
      3. Use the user's configured `mono` font-variation-settings by default.
      4. Correct the odd `em` font sizing in all browsers.
      */
  
    code,
    kbd,
    samp,
    pre {
      font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas,
        "Liberation Mono", "Courier New", monospace;
      /* 1 */
      font-feature-settings: normal;
      /* 2 */
      font-variation-settings: normal;
      /* 3 */
      font-size: 1em;
      /* 4 */
    }
  
    /*
      Add the correct font size in all browsers.
      */
  
    small {
      font-size: 80%;
    }
  
    /*
      Prevent `sub` and `sup` elements from affecting the line height in all browsers.
      */
  
    sub,
    sup {
      font-size: 75%;
      line-height: 0;
      position: relative;
      vertical-align: baseline;
    }
  
    sub {
      bottom: -0.25em;
    }
  
    sup {
      top: -0.5em;
    }
  
    /*
      1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
      2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
      3. Remove gaps between table borders by default.
      */
  
    table {
      text-indent: 0;
      /* 1 */
      border-color: inherit;
      /* 2 */
      border-collapse: collapse;
      /* 3 */
    }
  
    /*
      1. Change the font styles in all browsers.
      2. Remove the margin in Firefox and Safari.
      3. Remove default padding in all browsers.
      */
  
    button,
    input,
    optgroup,
    select,
    textarea {
      font-family: inherit;
      /* 1 */
      font-feature-settings: inherit;
      /* 1 */
      font-variation-settings: inherit;
      /* 1 */
      font-size: 100%;
      /* 1 */
      font-weight: inherit;
      /* 1 */
      line-height: inherit;
      /* 1 */
      color: inherit;
      /* 1 */
      margin: 0;
      /* 2 */
      padding: 0;
      /* 3 */
    }
  
    /*
      Remove the inheritance of text transform in Edge and Firefox.
      */
  
    button,
    select {
      text-transform: none;
    }
  
    /*
      1. Correct the inability to style clickable types in iOS and Safari.
      2. Remove default button styles.
      */
  
    button,
    [type="button"],
    [type="reset"],
    [type="submit"] {
      -webkit-appearance: button;
      /* 1 */
      background-color: transparent;
      /* 2 */
      background-image: none;
      /* 2 */
    }
  
    /*
      Use the modern Firefox focus style for all focusable elements.
      */
  
    :-moz-focusring {
      outline: auto;
    }
  
    /*
      Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)
      */
  
    :-moz-ui-invalid {
      box-shadow: none;
    }
  
    /*
      Add the correct vertical alignment in Chrome and Firefox.
      */
  
    progress {
      vertical-align: baseline;
    }
  
    /*
      Correct the cursor style of increment and decrement buttons in Safari.
      */
  
    ::-webkit-inner-spin-button,
    ::-webkit-outer-spin-button {
      height: auto;
    }
  
    /*
      1. Correct the odd appearance in Chrome and Safari.
      2. Correct the outline style in Safari.
      */
  
    [type="search"] {
      -webkit-appearance: textfield;
      /* 1 */
      outline-offset: -2px;
      /* 2 */
    }
  
    /*
      Remove the inner padding in Chrome and Safari on macOS.
      */
  
    ::-webkit-search-decoration {
      -webkit-appearance: none;
    }
  
    /*
      1. Correct the inability to style clickable types in iOS and Safari.
      2. Change font properties to `inherit` in Safari.
      */
  
    ::-webkit-file-upload-button {
      -webkit-appearance: button;
      /* 1 */
      font: inherit;
      /* 2 */
    }
  
    /*
      Add the correct display in Chrome and Safari.
      */
  
    summary {
      display: list-item;
    }
  
    /*
      Removes the default spacing and border for appropriate elements.
      */
  
    blockquote,
    dl,
    dd,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    hr,
    figure,
    p,
    pre {
      margin: 0;
    }
  
    fieldset {
      margin: 0;
      padding: 0;
    }
  
    legend {
      padding: 0;
    }
  
    ol,
    ul,
    menu {
      list-style: none;
      margin: 0;
      padding: 0;
    }
  
    /*
      Reset default styling for dialogs.
      */
  
    dialog {
      padding: 0;
    }
  
    /*
      Prevent resizing textareas horizontally by default.
      */
  
    textarea {
      resize: vertical;
    }
  
    /*
      1. Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)
      2. Set the default placeholder color to the user's configured gray 400 color.
      */
  
    input::placeholder,
    textarea::placeholder {
      opacity: 1;
      /* 1 */
      color: #9ca3af;
      /* 2 */
    }
  
    /*
      Set the default cursor for buttons.
      */
  
    button,
    [role="button"] {
      cursor: pointer;
    }
  
    /*
      Make sure disabled buttons don't get the pointer cursor.
      */
  
    :disabled {
      cursor: default;
    }
  
    /*
      1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)
      2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)
         This can trigger a poorly considered lint error in some tools but is included by design.
      */
  
    img,
    svg,
    video,
    canvas,
    audio,
    iframe,
    embed,
    object {
      display: block;
      /* 1 */
      vertical-align: middle;
      /* 2 */
    }
  
    /*
      Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)
      */
  
    img,
    video {
      max-width: 100%;
      height: auto;
    }
  
    /* Make elements with the HTML hidden attribute stay hidden by default */
  
    [hidden] {
      display: none;
    }
  
    *,
    ::before,
    ::after {
      --tw-border-spacing-x: 0;
      --tw-border-spacing-y: 0;
      --tw-translate-x: 0;
      --tw-translate-y: 0;
      --tw-rotate: 0;
      --tw-skew-x: 0;
      --tw-skew-y: 0;
      --tw-scale-x: 1;
      --tw-scale-y: 1;
      --tw-pan-x:  ;
      --tw-pan-y:  ;
      --tw-pinch-zoom:  ;
      --tw-scroll-snap-strictness: proximity;
      --tw-gradient-from-position:  ;
      --tw-gradient-via-position:  ;
      --tw-gradient-to-position:  ;
      --tw-ordinal:  ;
      --tw-slashed-zero:  ;
      --tw-numeric-figure:  ;
      --tw-numeric-spacing:  ;
      --tw-numeric-fraction:  ;
      --tw-ring-inset:  ;
      --tw-ring-offset-width: 0px;
      --tw-ring-offset-color: #fff;
      --tw-ring-color: rgb(59 130 246 / 0.5);
      --tw-ring-offset-shadow: 0 0 #0000;
      --tw-ring-shadow: 0 0 #0000;
      --tw-shadow: 0 0 #0000;
      --tw-shadow-colored: 0 0 #0000;
      --tw-blur:  ;
      --tw-brightness:  ;
      --tw-contrast:  ;
      --tw-grayscale:  ;
      --tw-hue-rotate:  ;
      --tw-invert:  ;
      --tw-saturate:  ;
      --tw-sepia:  ;
      --tw-drop-shadow:  ;
      --tw-backdrop-blur:  ;
      --tw-backdrop-brightness:  ;
      --tw-backdrop-contrast:  ;
      --tw-backdrop-grayscale:  ;
      --tw-backdrop-hue-rotate:  ;
      --tw-backdrop-invert:  ;
      --tw-backdrop-opacity:  ;
      --tw-backdrop-saturate:  ;
      --tw-backdrop-sepia:  ;
    }
  
    ::backdrop {
      --tw-border-spacing-x: 0;
      --tw-border-spacing-y: 0;
      --tw-translate-x: 0;
      --tw-translate-y: 0;
      --tw-rotate: 0;
      --tw-skew-x: 0;
      --tw-skew-y: 0;
      --tw-scale-x: 1;
      --tw-scale-y: 1;
      --tw-pan-x:  ;
      --tw-pan-y:  ;
      --tw-pinch-zoom:  ;
      --tw-scroll-snap-strictness: proximity;
      --tw-gradient-from-position:  ;
      --tw-gradient-via-position:  ;
      --tw-gradient-to-position:  ;
      --tw-ordinal:  ;
      --tw-slashed-zero:  ;
      --tw-numeric-figure:  ;
      --tw-numeric-spacing:  ;
      --tw-numeric-fraction:  ;
      --tw-ring-inset:  ;
      --tw-ring-offset-width: 0px;
      --tw-ring-offset-color: #fff;
      --tw-ring-color: rgb(59 130 246 / 0.5);
      --tw-ring-offset-shadow: 0 0 #0000;
      --tw-ring-shadow: 0 0 #0000;
      --tw-shadow: 0 0 #0000;
      --tw-shadow-colored: 0 0 #0000;
      --tw-blur:  ;
      --tw-brightness:  ;
      --tw-contrast:  ;
      --tw-grayscale:  ;
      --tw-hue-rotate:  ;
      --tw-invert:  ;
      --tw-saturate:  ;
      --tw-sepia:  ;
      --tw-drop-shadow:  ;
      --tw-backdrop-blur:  ;
      --tw-backdrop-brightness:  ;
      --tw-backdrop-contrast:  ;
      --tw-backdrop-grayscale:  ;
      --tw-backdrop-hue-rotate:  ;
      --tw-backdrop-invert:  ;
      --tw-backdrop-opacity:  ;
      --tw-backdrop-saturate:  ;
      --tw-backdrop-sepia:  ;
    }
  
    .sr-only {
      position: absolute;
      width: 1px;
      height: 1px;
      padding: 0;
      margin: -1px;
      overflow: hidden;
      clip: rect(0, 0, 0, 0);
      white-space: nowrap;
      border-width: 0;
    }
  
    .collapse {
      visibility: collapse;
    }
  
    .absolute {
      position: absolute;
    }
  
    .relative {
      position: relative;
    }
  
    .inset-0 {
      inset: 0px;
    }
  
    .end-0 {
      inset-inline-end: 0px;
    }
  
    .top-0 {
      top: 0px;
    }
  
    .z-10 {
      z-index: 10;
    }
  
    .z-20 {
      z-index: 20;
    }
  
    .mx-10 {
      margin-left: 2.5rem;
      margin-right: 2.5rem;
    }
  
    .mx-auto {
      margin-left: auto;
      margin-right: auto;
    }
  
    .my-2 {
      margin-top: 0.5rem;
      margin-bottom: 0.5rem;
    }
  
    .mb-10 {
      margin-bottom: 2.5rem;
    }
  
    .mb-2 {
      margin-bottom: 0.5rem;
    }
  
    .ms-2 {
      margin-inline-start: 0.5rem;
    }
  
    .ms-2\.5 {
      margin-inline-start: 0.625rem;
    }
  
    .ms-3 {
      margin-inline-start: 0.75rem;
    }
  
    .mt-1 {
      margin-top: 0.25rem;
    }
  
    .mt-6 {
      margin-top: 1.5rem;
    }
  
    .block {
      display: block;
    }
  
    .inline-block {
      display: inline-block;
    }
  
    .inline {
      display: inline;
    }
  
    .flex {
      display: flex;
    }
  
    .inline-flex {
      display: inline-flex;
    }
  
    .hidden {
      display: none;
    }
  
    .h-10 {
      height: 2.5rem;
    }
  
    .h-2 {
      height: 0.5rem;
    }
  
    .h-2\.5 {
      height: 0.625rem;
    }
  
    .h-3 {
      height: 0.75rem;
    }
  
    .h-4 {
      height: 1rem;
    }
  
    .h-6 {
      height: 1.5rem;
    }
  
    .h-full {
      height: 100%;
    }
  
    .min-h-screen {
      min-height: 100vh;
    }
  
    .w-1\/3 {
      width: 33.333333%;
    }
  
    .w-10 {
      width: 2.5rem;
    }
  
    .w-2 {
      width: 0.5rem;
    }
  
    .w-2\.5 {
      width: 0.625rem;
    }
  
    .w-3 {
      width: 0.75rem;
    }
  
    .w-4 {
      width: 1rem;
    }
  
    .w-44 {
      width: 11rem;
    }
  
    .w-6 {
      width: 1.5rem;
    }
  
    .w-full {
      width: 100%;
    }
  
    .max-w-lg {
      max-width: 32rem;
    }
  
    .flex-shrink-0 {
      flex-shrink: 0;
    }
  
    .shrink-0 {
      flex-shrink: 0;
    }
  
    .-rotate-90 {
      --tw-rotate: -90deg;
      transform: translate(var(--tw-translate-x), var(--tw-translate-y))
        rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y))
        scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
    }
  
    .rotate-180 {
      --tw-rotate: 180deg;
      transform: translate(var(--tw-translate-x), var(--tw-translate-y))
        rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y))
        scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
    }
  
    .cursor-pointer {
      cursor: pointer;
    }
  
    .flex-col {
      flex-direction: column;
    }
  
    .items-center {
      align-items: center;
    }
  
    .justify-center {
      justify-content: center;
    }
  
    .justify-between {
      justify-content: space-between;
    }
  
    .gap-3 {
      gap: 0.75rem;
    }
  
    .space-x-2 > :not([hidden]) ~ :not([hidden]) {
      --tw-space-x-reverse: 0;
      margin-right: calc(0.5rem * var(--tw-space-x-reverse));
      margin-left: calc(0.5rem * calc(1 - var(--tw-space-x-reverse)));
    }
  
    .divide-y > :not([hidden]) ~ :not([hidden]) {
      --tw-divide-y-reverse: 0;
      border-top-width: calc(1px * calc(1 - var(--tw-divide-y-reverse)));
      border-bottom-width: calc(1px * var(--tw-divide-y-reverse));
    }
  
    .divide-gray-100 > :not([hidden]) ~ :not([hidden]) {
      --tw-divide-opacity: 1;
      border-color: rgb(243 244 246 / var(--tw-divide-opacity));
    }
  
    .overflow-hidden {
      overflow: hidden;
    }
  
    .whitespace-nowrap {
      white-space: nowrap;
    }
  
    .rounded-full {
      border-radius: 9999px;
    }
  
    .rounded-lg {
      border-radius: 0.5rem;
    }
  
    .rounded-e-lg {
      border-start-end-radius: 0.5rem;
      border-end-end-radius: 0.5rem;
    }
  
    .rounded-s-lg {
      border-start-start-radius: 0.5rem;
      border-end-start-radius: 0.5rem;
    }
  
    .rounded-t-xl {
      border-top-left-radius: 0.75rem;
      border-top-right-radius: 0.75rem;
    }
  
    .border {
      border-width: 1px;
    }
  
    .border-b-0 {
      border-bottom-width: 0px;
    }
  
    .border-s-2 {
      border-inline-start-width: 2px;
    }
  
    .border-t-0 {
      border-top-width: 0px;
    }
  
    .border-blue-700 {
      --tw-border-opacity: 1;
      border-color: rgb(29 78 216 / var(--tw-border-opacity));
    }
  
    .border-gray-200 {
      --tw-border-opacity: 1;
      border-color: rgb(229 231 235 / var(--tw-border-opacity));
    }
  
    .border-gray-300 {
      --tw-border-opacity: 1;
      border-color: rgb(209 213 219 / var(--tw-border-opacity));
    }
  
    .border-s-gray-50 {
      --tw-border-opacity: 1;
      border-inline-start-color: rgb(249 250 251 / var(--tw-border-opacity));
    }
  
    .bg-blue-200 {
      --tw-bg-opacity: 1;
      background-color: rgb(191 219 254 / var(--tw-bg-opacity));
    }
  
    .bg-blue-700 {
      --tw-bg-opacity: 1;
      background-color: rgb(29 78 216 / var(--tw-bg-opacity));
    }
  
    .bg-gray-100 {
      --tw-bg-opacity: 1;
      background-color: rgb(243 244 246 / var(--tw-bg-opacity));
    }
  
    .bg-gray-50 {
      --tw-bg-opacity: 1;
      background-color: rgb(249 250 251 / var(--tw-bg-opacity));
    }
  
    .bg-green-100 {
      --tw-bg-opacity: 1;
      background-color: rgb(220 252 231 / var(--tw-bg-opacity));
    }
  
    .bg-green-200 {
      --tw-bg-opacity: 1;
      background-color: rgb(187 247 208 / var(--tw-bg-opacity));
    }
  
    .bg-orange-200 {
      --tw-bg-opacity: 1;
      background-color: rgb(254 215 170 / var(--tw-bg-opacity));
    }
  
    .bg-violet-100 {
      --tw-bg-opacity: 1;
      background-color: rgb(237 233 254 / var(--tw-bg-opacity));
    }
  
    .bg-white {
      --tw-bg-opacity: 1;
      background-color: rgb(255 255 255 / var(--tw-bg-opacity));
    }
  
    .bg-yellow-100 {
      --tw-bg-opacity: 1;
      background-color: rgb(254 249 195 / var(--tw-bg-opacity));
    }
  
    .bg-\[url\(\/img\/grid\.svg\)\] {
      background-image: url(/img/grid.svg);
    }
  
    .bg-center {
      background-position: center;
    }
  
    .p-0 {
      padding: 0px;
    }
  
    .p-0\.5 {
      padding: 0.125rem;
    }
  
    .p-1 {
      padding: 0.25rem;
    }
  
    .p-2 {
      padding: 0.5rem;
    }
  
    .p-2\.5 {
      padding: 0.625rem;
    }
  
    .p-5 {
      padding: 1.25rem;
    }
  
    .px-2 {
      padding-left: 0.5rem;
      padding-right: 0.5rem;
    }
  
    .px-4 {
      padding-left: 1rem;
      padding-right: 1rem;
    }
  
    .px-5 {
      padding-left: 1.25rem;
      padding-right: 1.25rem;
    }
  
    .px-6 {
      padding-left: 1.5rem;
      padding-right: 1.5rem;
    }
  
    .py-2 {
      padding-top: 0.5rem;
      padding-bottom: 0.5rem;
    }
  
    .py-2\.5 {
      padding-top: 0.625rem;
      padding-bottom: 0.625rem;
    }
  
    .py-6 {
      padding-top: 1.5rem;
      padding-bottom: 1.5rem;
    }
  
    .pb-2 {
      padding-bottom: 0.5rem;
    }
  
    .pb-8 {
      padding-bottom: 2rem;
    }
  
    .pt-10 {
      padding-top: 2.5rem;
    }
  
    .text-center {
      text-align: center;
    }
  
    .text-sm {
      font-size: 0.875rem;
      line-height: 1.25rem;
    }
  
    .text-xs {
      font-size: 0.75rem;
      line-height: 1rem;
    }
  
    .font-bold {
      font-weight: 700;
    }
  
    .font-medium {
      font-weight: 500;
    }
  
    .font-semibold {
      font-weight: 600;
    }
  
    .text-blue-800 {
      --tw-text-opacity: 1;
      color: rgb(30 64 175);
    }
  
    .text-gray-400 {
      --tw-text-opacity: 1;
      color: rgb(156 163 175);
    }
  
    .text-gray-500 {
      --tw-text-opacity: 1;
      color: rgb(107 114 128);
    }
  
    .text-gray-600 {
      --tw-text-opacity: 1;
      color: rgb(75 85 99);
    }
  
    .text-gray-700 {
      --tw-text-opacity: 1;
      color: rgb(55 65 81);
    }
  
    .text-gray-900 {
      --tw-text-opacity: 1;
      color: rgb(17 24 39);
    }
  
    .text-white {
      --tw-text-opacity: 1;
      color: rgb(255 255 255);
    }
  
    .shadow {
      --tw-shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
      --tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color),
        0 1px 2px -1px var(--tw-shadow-color);
      box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000),
        var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
    }
  
    .shadow-xl {
      --tw-shadow: 0 20px 25px -5px rgb(0 0 0 / 0.1),
        0 8px 10px -6px rgb(0 0 0 / 0.1);
      --tw-shadow-colored: 0 20px 25px -5px var(--tw-shadow-color),
        0 8px 10px -6px var(--tw-shadow-color);
      box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000),
        var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
    }
  
    .ring-1 {
      --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0
        var(--tw-ring-offset-width) var(--tw-ring-offset-color);
      --tw-ring-shadow: var(--tw-ring-inset) 0 0 0
        calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);
      box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow),
        var(--tw-shadow, 0 0 #0000);
    }
  
    .ring-gray-900\/5 {
      --tw-ring-color: rgb(17 24 39 / 0.05);
    }
  
    .sequence_container {
      overflow-wrap: anywhere;
      counter-reset: sequence;
    }
  
    .sequence_container .sequence__chunk {
      display: inline-block;
      margin: 0.1rem 0 1rem 1rem;
      /* width: 10ch; */
      position: relative;
      white-space: nowrap;
    }
  
    .sequence_container .sequence__chunk:not(:last-child):before,
    .sequence_container .sequence__chunk--display-last:before {
      content: counter(sequence);
      counter-increment: sequence 10;
      position: absolute;
      top: -0.8em;
      right: 0;
      opacity: 0.5;
      font-weight: bold;
    }
  
    .sequence-container .sequence__chunk::after {
      content: "";
      position: absolute;
      bottom: 0;
      left: 0;
      right: 0;
      transform-origin: left;
      transform: scaleX(0.1);
      box-shadow: var(--box-shadow);
    }
  
    .sequence__chunk span {
      padding: 0 0.05rem;
    }
  
    .hover\:bg-blue-800:hover {
      --tw-bg-opacity: 1;
      background-color: rgb(30 64 175 / var(--tw-bg-opacity));
    }
  
    .hover\:bg-gray-100:hover {
      --tw-bg-opacity: 1;
      background-color: rgb(243 244 246 / var(--tw-bg-opacity));
    }
  
    .hover\:bg-gray-200:hover {
      --tw-bg-opacity: 1;
      background-color: rgb(229 231 235 / var(--tw-bg-opacity));
    }
  
    .hover\:font-bold:hover {
      font-weight: 700;
    }
  
    .focus\:border-blue-500:focus {
      --tw-border-opacity: 1;
      border-color: rgb(59 130 246 / var(--tw-border-opacity));
    }
  
    .focus\:outline-none:focus {
      outline: 2px solid transparent;
      outline-offset: 2px;
    }
  
    .focus\:ring-4:focus {
      --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0
        var(--tw-ring-offset-width) var(--tw-ring-offset-color);
      --tw-ring-shadow: var(--tw-ring-inset) 0 0 0
        calc(4px + var(--tw-ring-offset-width)) var(--tw-ring-color);
      box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow),
        var(--tw-shadow, 0 0 #0000);
    }
  
    .focus\:ring-blue-300:focus {
      --tw-ring-opacity: 1;
      --tw-ring-color: rgb(147 197 253 / var(--tw-ring-opacity));
    }
  
    .focus\:ring-blue-500:focus {
      --tw-ring-opacity: 1;
      --tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity));
    }
  
    .focus\:ring-gray-100:focus {
      --tw-ring-opacity: 1;
      --tw-ring-color: rgb(243 244 246 / var(--tw-ring-opacity));
    }
  
    .focus\:ring-gray-200:focus {
      --tw-ring-opacity: 1;
      --tw-ring-color: rgb(229 231 235 / var(--tw-ring-opacity));
    }
  
    @media (min-width: 640px) {
      .sm\:mx-auto {
        margin-left: auto;
        margin-right: auto;
      }
  
      .sm\:rounded-lg {
        border-radius: 0.5rem;
      }
  
      .sm\:px-10 {
        padding-left: 2.5rem;
        padding-right: 2.5rem;
      }
  
      .sm\:py-12 {
        padding-top: 3rem;
        padding-bottom: 3rem;
      }
    }
  
    .rtl\:text-right:where([dir="rtl"], [dir="rtl"] *) {
      text-align: right;
    }
  
    @media (prefers-color-scheme: dark) {
      .dark\:border-gray-600 {
        --tw-border-opacity: 1;
        border-color: rgb(75 85 99 / var(--tw-border-opacity));
      }
  
      .dark\:border-gray-700 {
        --tw-border-opacity: 1;
        border-color: rgb(55 65 81 / var(--tw-border-opacity));
      }
  
      .dark\:border-s-gray-700 {
        --tw-border-opacity: 1;
        border-inline-start-color: rgb(55 65 81 / var(--tw-border-opacity));
      }
  
      .dark\:bg-blue-600 {
        --tw-bg-opacity: 1;
        background-color: rgb(37 99 235 / var(--tw-bg-opacity));
      }
  
      .dark\:bg-gray-600 {
        --tw-bg-opacity: 1;
        background-color: rgb(75 85 99 / var(--tw-bg-opacity));
      }
  
      .dark\:bg-gray-700 {
        --tw-bg-opacity: 1;
        background-color: rgb(55 65 81 / var(--tw-bg-opacity));
      }
  
      .dark\:bg-gray-900 {
        --tw-bg-opacity: 1;
        background-color: rgb(17 24 39 / var(--tw-bg-opacity));
      }
  
      .dark\:text-gray-200 {
        --tw-text-opacity: 1;
        color: rgb(229 231 235);
      }
  
      .dark\:text-gray-300 {
        --tw-text-opacity: 1;
        color: rgb(209 213 219);
      }
  
      .dark\:text-gray-400 {
        --tw-text-opacity: 1;
        color: rgb(156 163 175);
      }
  
      .dark\:text-white {
        --tw-text-opacity: 1;
        color: rgb(255 255 255);
      }
  
      .dark\:placeholder-gray-400::placeholder {
        --tw-placeholder-opacity: 1;
        color: rgb(156 163 175 / var(--tw-placeholder-opacity));
      }
  
      .dark\:hover\:bg-blue-700:hover {
        --tw-bg-opacity: 1;
        background-color: rgb(29 78 216 / var(--tw-bg-opacity));
      }
  
      .dark\:hover\:bg-gray-600:hover {
        --tw-bg-opacity: 1;
        background-color: rgb(75 85 99 / var(--tw-bg-opacity));
      }
  
      .dark\:hover\:bg-gray-800:hover {
        --tw-bg-opacity: 1;
        background-color: rgb(31 41 55 / var(--tw-bg-opacity));
      }
  
      .dark\:hover\:text-white:hover {
        --tw-text-opacity: 1;
        color: rgb(255 255 255);
      }
  
      .dark\:focus\:border-blue-500:focus {
        --tw-border-opacity: 1;
        border-color: rgb(59 130 246 / var(--tw-border-opacity));
      }
  
      .dark\:focus\:ring-blue-500:focus {
        --tw-ring-opacity: 1;
        --tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity));
      }
  
      .dark\:focus\:ring-blue-800:focus {
        --tw-ring-opacity: 1;
        --tw-ring-color: rgb(30 64 175 / var(--tw-ring-opacity));
      }
  
      .dark\:focus\:ring-gray-700:focus {
        --tw-ring-opacity: 1;
        --tw-ring-color: rgb(55 65 81 / var(--tw-ring-opacity));
      }
  
      .dark\:focus\:ring-gray-800:focus {
        --tw-ring-opacity: 1;
        --tw-ring-color: rgb(31 41 55 / var(--tw-ring-opacity));
      }
    }